@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2006-2018, University of Amsterdam
+    Copyright (c)  2006-2020, University of Amsterdam
                               VU University Amsterdam
                               CWI, Amsterdam
     All rights reserved.
@@ -104,8 +104,14 @@
 :- use_module(doc_index).
 :- use_module(doc_util).
 :- use_module(library(solution_sequences)).
+:- use_module(library(error)).
+:- use_module(library(occurs)).
+:- use_module(library(prolog_source)).
+:- use_module(library(prolog_xref)).
+
 :- include(hooks).
 
+
 /** <module> PlDoc HTML backend
 
 This  module  translates  the  Herbrand   term  from  the  documentation
@@ -512,7 +518,7 @@ private(Module:PI, Options) :-
 private(Module:PI, _Options) :-
     module_property(Module, file(_)),      % A loaded module
     !,
-    export_list(Module, Exports),
+    module_property(Module, exports(Exports)),
     \+ ( member(PI2, Exports),
          eq_pi(PI, PI2)
        ).
@@ -1663,6 +1669,13 @@ pred_head(Head) -->                     % Postfix operators
     html([ var(class=arglist, \pred_arg(Arg, 1)),
            ' ', b(class=pred, Functor)
          ]).
+pred_head({Head}) -->
+    !,
+    html([ b(class=pred, '{'),
+           var(class=arglist,
+               \pred_args([Head], 1)),
+           b(class=pred, '}')
+         ]).
 pred_head(Head) -->                     % Plain terms
     { Head =.. [Functor|Args] },
     html([ b(class=pred, Functor),
