@@ -71,6 +71,9 @@
 /* Define if you have shares using the notation //host/share */
 #define O_HASSHARES 1
 
+/* Define if you have shares using the notation //netbios/share */
+#define O_NETBIOS 1
+
 /* Maximum length of a path-name.  Note XOS! */
 #define MAXPATHLEN 512
 
