@@ -799,10 +799,10 @@ set_prolog_flag_unlocked(Module m, atom_t k, term_t value, int flags ARG_LD)
 	  clear(m, M_VARPREFIX);
       } else if ( k == ATOM_debug )
       { if ( val )
-	{ rval = debugmode(DBG_ALL, NULL);
+	{ debugmode(DBG_ALL, NULL);
 	} else
-	{ rval = ( tracemode(FALSE, NULL) &&
-		   debugmode(DBG_OFF, NULL) );
+	{ tracemode(FALSE, NULL);
+	  debugmode(DBG_OFF, NULL);
 	}
       } else if ( k == ATOM_debugger_show_context )
       { debugstatus.showContext = val;
@@ -838,7 +838,7 @@ set_prolog_flag_unlocked(Module m, atom_t k, term_t value, int flags ARG_LD)
 	}
       }
 					/* set the flag value */
-      if ( f->index > 0 && rval )
+      if ( f->index > 0 )
       { unsigned int mask = (unsigned int)1 << (f->index-1);
 
 	if ( val )
